@@ -1,12 +1,14 @@
 import os
 from threading import Thread
 from time import sleep
-from infiniguard_api.lib.rest.common import http_code
 
-from infiniguard_api.common import const, messages
+from infiniguard_api.common.const import INFINIDAT_ROLE, ADMIN_ROLE, TECHNICIAN_ROLE
+from infiniguard_api.lib.rest.common import http_code, allowed_roles, requires_approval
+
+from infiniguard_api.common import messages
 from infiniguard_api.lib.hw.cli_handler import run_syscli
 from infiniguard_api.lib.logging import iguard_logging
-from infiniguard_api.lib.rest.common import error_handler
+from infiniguard_api.lib.rest.common import error_handler, build_empty_response
 from infiniguard_api.lib.hw.output_parser import check_command_successful
 
 
@@ -14,10 +16,12 @@ log = iguard_logging.get_logger(__name__)
 
 
 @error_handler
+@requires_approval('DDE App will reboot.')
+@allowed_roles(roles=[INFINIDAT_ROLE, ADMIN_ROLE, TECHNICIAN_ROLE])
 def reboot(**kwargs):
-    wait_time = kwargs.pop('wait_time', const.REBOOT_WAIT_TIME_S)
+    wait_time = kwargs.pop('wait_time', 0)
     reboot_thread(wait_time)
-    return dict(message=messages.DDE_REBOOTING_MSG.format(wait_time)), http_code.OK
+    return build_empty_response(), http_code.OK
 
 
 def reboot_system(wait):
@@ -30,7 +34,6 @@ def reboot_system(wait):
 
 
 def reboot_thread(wait_time):
-    wait_time = const.REBOOT_WAIT_TIME_S if not wait_time else wait_time
     thread = Thread(target=reboot_system, args=(wait_time,))
     log.warn(messages.REBOOTING_TIME_WARNING.format(wait_time))
     thread.start()
